<div align="center" style="display: flex; flex-direction: column; gap: 0;">
    <img src="https://raw.githubusercontent.com/tombi-toml/tombi/refs/heads/main/docs/public/tombi.svg" alt="Logo" style="display: block; margin: 0;">
    <img src="https://raw.githubusercontent.com/tombi-toml/tombi/refs/heads/main/docs/public/demo.gif" style="display: block; margin: 0;" />
</div>

<div align="center">

[![VS Code Marketplace](https://img.shields.io/visual-studio-marketplace/v/tombi-toml.tombi?label=VS%20Code%20Marketplace&logo=visual-studio-code&labelColor=374151&color=60a5fa)](https://marketplace.visualstudio.com/items?itemName=tombi-toml.tombi)
[![Open VSX Registry](https://img.shields.io/open-vsx/v/tombi-toml/tombi?label=Open%20VSX%20Registry&labelColor=374151&color=60a5fa)](https://open-vsx.org/extension/tombi-toml/tombi)
[![JetBrains Marketplace](https://img.shields.io/jetbrains/plugin/v/28017-tombi?label=JetBrains%20Marketplace&labelColor=374151&color=60a5fa)](https://plugins.jetbrains.com/plugin/28017-tombi)
[![Zed Extension](https://img.shields.io/badge/Zed%20Extension-v0.2.0-blue?labelColor=374151&color=60a5fa)](https://zed.dev/extensions/tombi)
[![homebrew](https://img.shields.io/homebrew/v/tombi.svg?labelColor=374151&color=60a5fa)](https://formulae.brew.sh/formula/tombi)
[![pypi](https://img.shields.io/pypi/v/tombi.svg?labelColor=374151&color=60a5fa)](https://pypi.python.org/pypi/tombi)
[![npm](https://img.shields.io/npm/v/tombi.svg?labelColor=374151&color=60a5fa)](https://www.npmjs.com/package/tombi)
[![toml-test](https://github.com/tombi-toml/tombi/actions/workflows/toml-test.yml/badge.svg)](https://github.com/tombi-toml/tombi/actions)
[![GitHub license](https://badgen.net/github/license/tombi-toml/tombi?style=flat-square&labelColor=374151)](https://github.com/tombi-toml/tombi/blob/main/LICENSE)

</div>

<br>

<div align="center">
    <h2 align="center" style="font-size: 2.0em; margin-bottom: 30px;">
        <span aria-hidden="true">🦅&nbsp;</span>
        <strong>TOML Toolkit</strong>
        <span aria-hidden="true">&nbsp;🦅</span>
    </h2>
    Tombi(鳶 <a href="https://ipa-reader.com/?text=toɴbi" style="font-size: 1.2em; color: #007acc; text-decoration: none;">/toɴbi/</a>) provides a Formatter, Linter, and Language Server
    <br><br>
    <span aria-hidden="true">📚</span>
    <a href="https://tombi-toml.github.io/tombi" style="font-size: 1.2em; color: #007acc; text-decoration: none;">Documentation</a>
    <span aria-hidden="true">📚</span>
</div>

<br>

<div align="center">
<h2 align="center" style="font-size: 2.0em; margin-bottom: 30px;">
<strong>Quick Start</strong>
</h2>

To quickly try out Tombi's formatter, you can run:

<code style="display: block; white-space: pre-wrap;">    uvx tombi format    </code>
</div>

<div align="center">
    <h2 align="center" style="font-size: 2.0em; margin-bottom: 30px;">
        <strong>Support us</strong>
    </h2>
    If you like this project and would like to support us
    <br><br>
    <a href="https://github.com/sponsors/tombi-toml">
        <img src="https://img.shields.io/static/v1?label=Sponsor&message=%E2%9D%A4&logo=GitHub&color=ff69b4" alt="GitHub Sponsor">
    </a>
</div>
